pub struct OrderUpdated {
pub is_create: bool,
pub id: u64,
pub ts: i64,
pub slot: u64,
pub store: Pubkey,
pub order: Pubkey,
pub market_token: Pubkey,
pub owner: Pubkey,
pub params: OrderParamsForEvent,
}Expand description
An event indicating that an order is created or updated.
Notes
- For compatibility reasons, the
OrderUpdatedevent is not emitted by the (deprecated)create_orderandupdate_orderinstructions. As a result, there is no guarantee that every order will have correspondingOrderUpdatedevents.
Fields
is_create: boolWhether it is a create event.
id: u64Action id.
ts: i64Timestamp.
slot: u64Slot.
store: PubkeyStore.
order: PubkeyOrder.
market_token: PubkeyMarket token.
owner: PubkeyOwner.
params: OrderParamsForEventParameters.