pub struct CreateVirtualInventoryForSwaps {
pub index: u32,
pub long_amount_decimals: u8,
pub short_amount_decimals: u8,
}Expand description
Instruction.
Fields
index: u32long_amount_decimals: u8short_amount_decimals: u8Trait Implementations
Sourceimpl BorshDeserialize for CreateVirtualInventoryForSwaps
impl BorshDeserialize for CreateVirtualInventoryForSwaps
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for CreateVirtualInventoryForSwaps
impl Discriminator for CreateVirtualInventoryForSwaps
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more