pub struct CreateVirtualInventoryForSwapsBumps {
pub virtual_inventory: u8,
}Fields
virtual_inventory: u8Trait Implementations
Sourceimpl<'info> Accounts<'info, CreateVirtualInventoryForSwapsBumps> for CreateVirtualInventoryForSwaps<'info>where
'info: 'info,
impl<'info> Accounts<'info, CreateVirtualInventoryForSwapsBumps> for CreateVirtualInventoryForSwaps<'info>where
'info: 'info,
Sourcefn try_accounts(
__program_id: &Pubkey,
__accounts: &mut &'info [AccountInfo<'info>],
__ix_data: &[u8],
__bumps: &mut CreateVirtualInventoryForSwapsBumps,
__reallocs: &mut BTreeSet<Pubkey>,
) -> Result<Self>
fn try_accounts( __program_id: &Pubkey, __accounts: &mut &'info [AccountInfo<'info>], __ix_data: &[u8], __bumps: &mut CreateVirtualInventoryForSwapsBumps, __reallocs: &mut BTreeSet<Pubkey>, ) -> Result<Self>
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a
Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read moreAuto Trait Implementations
impl Freeze for CreateVirtualInventoryForSwapsBumps
impl RefUnwindSafe for CreateVirtualInventoryForSwapsBumps
impl Send for CreateVirtualInventoryForSwapsBumps
impl Sync for CreateVirtualInventoryForSwapsBumps
impl Unpin for CreateVirtualInventoryForSwapsBumps
impl UnsafeUnpin for CreateVirtualInventoryForSwapsBumps
impl UnwindSafe for CreateVirtualInventoryForSwapsBumps